pub struct StyleSource { /* private fields */ }Expand description
A struct that can be used as a source to create a Style or
GlobalStyle.
This struct is usually created by css! macro.
You can also get a StyleSource instance from a string or a Sheet by calling .into().
use stylist::yew::Global;
use stylist::{css, StyleSource};
use yew::prelude::*;
let s: StyleSource = css!("color: red;");
let rendered = html! {<div class={s.clone()} />};
let global_rendered = html! {<Global css={s} />};Trait Implementations
Sourceimpl Clone for StyleSource
impl Clone for StyleSource
Sourcefn clone(&self) -> StyleSource
fn clone(&self) -> StyleSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StyleSource
impl Debug for StyleSource
Sourceimpl From<Sheet> for StyleSource
impl From<Sheet> for StyleSource
Sourcefn from(sheet: Sheet) -> StyleSource
fn from(sheet: Sheet) -> StyleSource
Converts to this type from the input type.
Sourceimpl From<StyleSource> for Classes
Available on crate feature yew only.
impl From<StyleSource> for Classes
Available on crate feature
yew only.Sourcefn from(style_src: StyleSource) -> Self
fn from(style_src: StyleSource) -> Self
Converts to this type from the input type.
Sourceimpl FromStr for StyleSource
Available on crate feature parser only.
impl FromStr for StyleSource
Available on crate feature
parser only.Sourceimpl IntoPropValue<Classes> for StyleSource
Available on crate feature yew only.
impl IntoPropValue<Classes> for StyleSource
Available on crate feature
yew only.Sourcefn into_prop_value(self) -> Classes
fn into_prop_value(self) -> Classes
Convert
self to a value of a Properties struct.Sourceimpl<'a> IntoPropValue<StyleSource> for &'a str
Available on crate feature parser only.
impl<'a> IntoPropValue<StyleSource> for &'a str
Available on crate feature
parser only.Sourcefn into_prop_value(self) -> StyleSource
fn into_prop_value(self) -> StyleSource
Convert
self to a value of a Properties struct.Sourceimpl<'a> IntoPropValue<StyleSource> for Cow<'a, str>
Available on crate feature parser only.
impl<'a> IntoPropValue<StyleSource> for Cow<'a, str>
Available on crate feature
parser only.Sourcefn into_prop_value(self) -> StyleSource
fn into_prop_value(self) -> StyleSource
Convert
self to a value of a Properties struct.Sourceimpl IntoPropValue<StyleSource> for Sheet
Available on crate feature yew only.
impl IntoPropValue<StyleSource> for Sheet
Available on crate feature
yew only.Sourcefn into_prop_value(self) -> StyleSource
fn into_prop_value(self) -> StyleSource
Convert
self to a value of a Properties struct.Sourceimpl IntoPropValue<StyleSource> for String
Available on crate feature parser only.
impl IntoPropValue<StyleSource> for String
Available on crate feature
parser only.Sourcefn into_prop_value(self) -> StyleSource
fn into_prop_value(self) -> StyleSource
Convert
self to a value of a Properties struct.Sourceimpl PartialEq for StyleSource
impl PartialEq for StyleSource
Sourceimpl<'a> TryFrom<&'a str> for StyleSource
Available on crate feature parser only.
impl<'a> TryFrom<&'a str> for StyleSource
Available on crate feature
parser only.Sourceimpl TryFrom<String> for StyleSource
Available on crate feature parser only.
impl TryFrom<String> for StyleSource
Available on crate feature
parser only.impl StructuralPartialEq for StyleSource